rtk-package: Rarefaction Tool Kit

rtk-packageR Documentation

Rarefaction Tool Kit

Description

Rarefy data, calculate diversity and plot the results.

Details

The DESCRIPTION file: This package was not yet installed at build time.
Index: This package was not yet installed at build time.
This package might be used to rarefy data and compute diversity measures. Rarefied tables can be returned to R and be further processed.

Author(s)

Paul Saary [aut, cre], Falk Hildebrand [aut]

Maintainer: Paul Saary <rtk@paulsaary.de>

References

Saary, Paul, et al. "RTK: efficient rarefaction analysis of large datasets." Bioinformatics (2017): btx206.

See Also

rtk, plot.rtk, collectors.curve


rtk documentation built on Jan. 31, 2026, 1:06 a.m.