| rtk-package | R Documentation |
Rarefy data, calculate diversity and plot the results.
The DESCRIPTION file:
This package was not yet installed at build time.
Index: This package was not yet installed at build time.
This package might be used to rarefy data and compute diversity measures. Rarefied tables can be returned to R and be further processed.
Paul Saary [aut, cre], Falk Hildebrand [aut]
Maintainer: Paul Saary <rtk@paulsaary.de>
Saary, Paul, et al. "RTK: efficient rarefaction analysis of large datasets." Bioinformatics (2017): btx206.
rtk, plot.rtk, collectors.curve
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.